==> attal_0.9.1.orig.tar.gz: attal-0.9.1/libClient/insideBuilding.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** insideBuilding.h
** display building on the inside view
**
** Version : $Id: insideBuilding.h,v 1.1.1.1 2003/06/15 19:02:02 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 04/11/2001
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

 
#ifndef INSIDEBUILDING_H
#define INSIDEBUILDING_H
 
 
// generic include files
// include files for QT
#include <qcanvas.h>
// application specific include files


class GenericInsideBuilding;

/*              ------------------------------
 *                         InsideBuilding
 *              ------------------------------ */



/** comment for the class */
class InsideBuilding : public QCanvasSprite
{

public:
	/** Constructor */
	InsideBuilding( int type, GenericInsideBuilding * build, QCanvas * );

	void select();

	void deselect();

	virtual void move( int x, int y );

	GenericInsideBuilding * getBuilding() { return _building; }

	/** Return RTTI */
	int rtti() const { return RTTI; };

	static const int RTTI;

protected:
	GenericInsideBuilding * _building;
};
 
#endif // INSIDEBUILDING_H

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/libClient/insideBuilding.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** insideBuilding.h
** display building on the inside view
**
** Version : $Id: insideBuilding.h,v 1.2 2004/12/05 19:19:22 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 04/11/2001
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

 
#ifndef INSIDEBUILDING_H
#define INSIDEBUILDING_H
 
 
// generic include files
// include files for QT
#include <qcanvas.h>
#include <qimage.h>
// application specific include files


class GenericInsideBuilding;

/*              ------------------------------
 *                         InsideBuilding
 *              ------------------------------ */

class InsideBuilding : public QCanvasRectangle
{

public:
	/** Constructor */
	InsideBuilding( int type, GenericInsideBuilding * build, QCanvas * canvas );
	
	//ImageItem( QImage img, QCanvas *canvas );
    
    	bool hit( const QPoint & ) const;

	void select();

	void deselect();

	virtual void move( int x, int y );

	GenericInsideBuilding * getBuilding() { return _building; }

	/** Return RTTI */
	int rtti() const { return RTTI; };

	static const int RTTI;

protected:
	void drawShape( QPainter & );
	
	GenericInsideBuilding * _building;
	QPixmap * _pixmap;
	QImage _image;
	uint _type;
};
 
#endif // INSIDEBUILDING_H
